@@ -37,6 +37,7 @@ class DocManager(DocManagerBase):
                  unique_key='_id', chunk_size=DEFAULT_MAX_BULK, **kwargs):
         # self.graph = Graph('http://127.0.0.1:7474/db/data')
         # self.graph = Graph('bolt://192.168.3.119:7687', auth=("neo4j", "neo4j"))
+        print(url)
         self.graph = Graph(url,auth=("neo4j", "neo4j"))
         self.auto_commit_interval = auto_commit_interval
         self.unique_key = unique_key
@@ -62,7 +63,10 @@ class DocManager(DocManagerBase):
                 ret = self.nodeExist(doubanId)
                 if ret == False:
                     if other_actor not in builder.director_list and other_actor not in builder.cast_list:
-                        tx.run(statement, {"parameters": other_actor[statement]})
+                        print('-'*10 + doubanId)
+                        cypher = statement.replace('$parameters',str(other_actor[statement]).replace("'_id'","_id").replace("'actorName'","actorName")).replace("'doubanId'","doubanId").replace("'sex'","sex")
+                        print(cypher)
+                        tx.run(cypher=cypher)
                 else:
                     pass
 
@@ -71,7 +75,9 @@ class DocManager(DocManagerBase):
                 doubanId = director[statement]['doubanId']
                 ret = self.nodeExist(doubanId)
                 if ret == False:
-                    tx.run(statement, {"parameters": director[statement]})
+                    cypher = statement.replace('$parameters',str(director[statement]).replace("'_id'","_id").replace("'actorName'","actorName")).replace("'doubanId'","doubanId").replace("'sex'","sex")
+                    tx.run(cypher=cypher)
+                    # tx.run(statement, {"parameters": director[statement]})
                 else:
                     self.director.append(ret)
 
@@ -81,7 +87,9 @@ class DocManager(DocManagerBase):
                 ret = self.nodeExist(doubanId)
                 if ret == False:
                     if cast not in builder.director_list and cast not in builder.other_postion_list:
-                        tx.run(statement, {"parameters": cast[statement]})
+                        cypher = statement.replace('$parameters',str(cast[statement]).replace("'_id'", "_id").replace("'actorName'", "actorName")).replace("'doubanId'","doubanId").replace("'sex'","sex")
+                        tx.run(cypher=cypher)
+                        # tx.run(statement, {"parameters": cast[statement]})
                 else:
                     self.actor.append(ret)
 
@@ -93,9 +101,10 @@ class DocManager(DocManagerBase):
                         id_ = actor_[actor]['doubanId']
                         program_id = builder.parameters['programId']
                         type = "{" + " program_id:{},count:1".format([program_id]) + "}"
-                        tx.run(self.creat_relationship(id, id_, type,program_id))
+                        cypher = self.creat_relationship(id, id_, type,program_id)
+                        tx.run(cypher=cypher)
 
-        tx.commit()
+        self.graph.commit(tx)
 
     def update(self, document_id, update_spec, namespace, timestamp):
         pass
@@ -136,7 +145,7 @@ class DocManager(DocManagerBase):
         a=a
         director_doubanId = "{" + "doubanId:'{}'".format(doubanid) + "}"
         statement = 'MATCH (n{a}),(n1{b}),p=(n)-[r:Director_Actor]-(n1)  return r.count'.format(a=doubanId, b=director_doubanId)
-        count = self.graph.begin().run(statement).data()
+        count = self.graph.run(statement).data()
         if count != []:
             statement = 'MATCH (n{a}),(n1{b}),p=(n)-[r:Director_Actor]-(n1)  return r.program_id'.format(a=doubanId,b=director_doubanId)
             programId = self.graph.begin().run(statement).data()
